@@ -42,8 +42,8 @@ Base Class
     :exclude-members:
     :special-members: __hash__, __eq__, __repr__
 
-Idea Liquid Class
-=================
+Ideal Liquid Class
+==================
 
 .. autoclass:: IdealSolution
     :members: to_T_xs, GE, dGE_dT, d2GE_dT2, d3GE_dT3, d2GE_dTdxs, dGE_dxs, d2GE_dxixjs, d3GE_dxixjxks
@@ -285,8 +285,9 @@ class GibbsExcess(object):
     '''When set, this will be the limiting mole fraction used to approximate
     the :obj:`gammas_infinite_dilution` calculation. This is important
     as not all models can mathematically be evaluated at zero mole-fraction.'''
-
-    __full_path__ = "%s.%s" %(__module__, __qualname__)
+    
+    def __init_subclass__(cls):
+        cls.__full_path__ = "%s.%s" %(cls.__module__, cls.__qualname__)
 
     def __repr__(self):
         r'''Method to create a string representation of the state of the model.
@@ -1042,7 +1043,8 @@ class IdealSolution(GibbsExcess):
     [0.0, 0.0, 0.0, 0.0]
     '''
     model_attriubtes = ()
-    __full_path__ = "%s.%s" %(__module__, __qualname__)
+    
+    model_id = 0
 
     def __init__(self, T=None, xs=None):
         if T is not None:
